==> flulm_auth-1.1.5.tar.gz: lib/src/page/awesome_web_view.dart <==
import 'package:flulm_auth/src/aes/awesome_aes_encryption.dart';
import 'package:flulm_auth/src/model/result_data.dart';
import 'package:flulm_auth/src/utils/constant.dart';
import 'package:flulm_auth/src/utils/http_manager.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:uuid/uuid.dart';
import 'package:webview_flutter/webview_flutter.dart';
import 'dart:convert';

class AwesomeWebView extends StatefulWidget{

  String url;
  String language;
  int isTest;
  bool supportScan;

  AwesomeWebView(this.isTest,this.url, this.language,this.supportScan);

  @override
  _AwesomeWebViewState createState() => _AwesomeWebViewState();
}

class _AwesomeWebViewState extends State<AwesomeWebView> {
  WebViewController _webViewController;

  @override
  void initState() {
    debugPrint("AwesomeWebView === initState");
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return WebView(
      userAgent: Constant.userAgentSuffix + widget.language,
      //链接编码
      initialUrl: Uri.encodeFull(widget.url),
      javascriptMode: JavascriptMode.unrestricted,
      onWebViewCreated: (WebViewController controller) {
        debugPrint("onWebViewCreated===");
        _webViewController = controller;
      },
      javascriptChannels: <JavascriptChannel>[
        Constant.alertJavascriptChannel(_dispatchJs),
      ].toSet(),
      navigationDelegate: (NavigationRequest request) {
        if (!request.url.startsWith('http')) {
          return NavigationDecision.prevent;
        }
        debugPrint('allowing navigation to $request');
        return NavigationDecision.navigate;
      },
      onPageFinished: (String url) {
        debugPrint("onPageFinished=" + url);
      },
      debuggingEnabled: Constant.isDebug,
    );
  }

  void _dispatchJs(String method, Map<String, dynamic> jsonData) {
    switch (method) {
      case "getLoginCodeSuccess":
        {
          onAuthResultCall(0, jsonData['message'], jsonData['code']);
          break;
        }
      case "onPayResultCall":
        {
          onPayResultCall(jsonData['code'], jsonData['message'],
              jsonData['result_data'].toString());
          break;
        }
      case "closePage":
        {
          closePage(jsonData['code']);
          break;
        }
      case "callData":
        {
          callData(jsonData);
        }
        break;
      default:
        {
          debugPrint("没有匹配");
        }
        break;
    }
  }

  void callData(Map<String, dynamic> jsonData) async {
    debugPrint("callData = " +jsonEncode(jsonData));
    String  csrf = Uuid().v1().toString();
    var options = AwesomeAesEncryption.getOptions(csrf: csrf);
    var sdkApi = AwesomeAesEncryption.getSDKApi(widget.isTest);

    Map map = Map();
    final String callback = jsonData["callback"];
    if(jsonData.containsKey("params")){
      Map<String, dynamic> params = jsonData["params"];
      params.forEach((key, value) {
        map[key] = value;
      });
    }
    map["from"] = "flutter-" + defaultTargetPlatform.toString();
    map["noscan"] = widget.supportScan ? 0 : 1;
    map["t"] = DateTime.now().millisecondsSinceEpoch;

    var encrypt_key = AwesomeAesEncryption.getEncryptKey(widget.isTest);
    var beforeMD5 = "$encrypt_key${csrf}";
    var keyIv = AwesomeAesEncryption.encodeMd5(beforeMD5);

    Map post_data = Map();
    post_data["post_data"] = AwesomeAesEncryption.dataEncrypt(keyIv, jsonEncode(map));

    debugPrint("post_data = " + jsonEncode(map));

    ResultData resultData = await HttpManager.getInstance(sdkApi)
        .post("?ct=web&ac=get_web_data", post_data,options: options,keyIv: keyIv);

    var result_json = jsonEncode(resultData);

    _webViewController.evaluateJavascript("$callback($result_json)");

  }

  void closePage(int status) {
    debugPrint("closePage == status=" + status.toString());
    if (status == 0) {
      Navigator.pop(context);
    } else {
      showExitDialog();
    }
  }

  void onAuthResultCall(int errorCode, String message, String code) {
    goBackError(errorCode, message, code);
  }

  void onPayResultCall(int code, String message, String respJsonData) {
    goBackError(code, message, respJsonData);
  }

  void goBackError(int errCode, String msg, String code) {
    Map<String, dynamic> map = Map();
    map['errCode'] = errCode;
    map['errStr'] = msg;
    //授权的code
    map['code'] = code;
    Navigator.pop(context, map);
  }

  void showExitDialog() {
    String title = "Are you sure to exit?";
    String btn = "Exit";
    if (widget.language == "zh-cn") {
      title = "是否确定退出？";
      btn = "退出";
    } else if (widget.language == "km") {
      title = "តើអ្នកប្រាកដជាចាកចេញឬ?";
      btn = "បោះបង់ការសិក្សា";
    }
    AlertDialog(
      content: Text(title),
      actions: <Widget>[
//        FlatButton(
//          child: Text("取消"),
//          onPressed: () => Navigator.of(context).pop(), //关闭对话框
//        ),
        FlatButton(
          child: Text(btn),
          onPressed: () {
            Navigator.pop(context); //关闭对话框
          },
        ),
      ],
    );
  }



}

==> flulm_auth-2.1.0.tar.gz: lib/src/page/awesome_web_view.dart <==
import 'package:flulm_auth/src/aes/awesome_aes_encryption.dart';
import 'package:flulm_auth/src/model/result_data.dart';
import 'package:flulm_auth/src/utils/constant.dart';
import 'package:flulm_auth/src/utils/http_manager.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:uuid/uuid.dart';
import 'package:webview_flutter/webview_flutter.dart';
import 'dart:convert';

class AwesomeWebView extends StatefulWidget{

  String? url;
  String? language;
  int? isTest;
  bool? supportScan;

  AwesomeWebView(this.isTest,this.url, this.language,this.supportScan);

  @override
  _AwesomeWebViewState createState() => _AwesomeWebViewState();
}

class _AwesomeWebViewState extends State<AwesomeWebView> {
  late WebViewController _webViewController;

  @override
  void initState() {
    debugPrint("AwesomeWebView === initState");
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return WebView(
      userAgent: Constant.userAgentSuffix + widget.language!,
      //链接编码
      initialUrl: Uri.encodeFull(widget.url!),
      javascriptMode: JavascriptMode.unrestricted,
      onWebViewCreated: (WebViewController controller) {
        debugPrint("onWebViewCreated===");
        _webViewController = controller;
      },
      javascriptChannels: <JavascriptChannel>[
        Constant.alertJavascriptChannel(_dispatchJs),
      ].toSet(),
      navigationDelegate: (NavigationRequest request) {
        if (!request.url.startsWith('http')) {
          return NavigationDecision.prevent;
        }
        debugPrint('allowing navigation to $request');
        return NavigationDecision.navigate;
      },
      onPageFinished: (String url) {
        debugPrint("onPageFinished=" + url);
      },
      debuggingEnabled: Constant.isDebug,
    );
  }

  void _dispatchJs(String? method, Map<String, dynamic>? jsonData) {
    switch (method) {
      case "getLoginCodeSuccess":
        {
          onAuthResultCall(0, jsonData!['message'], jsonData['code']);
          break;
        }
      case "onPayResultCall":
        {
          onPayResultCall(jsonData!['code'], jsonData['message'],
              jsonData['result_data'].toString());
          break;
        }
      case "closePage":
        {
          closePage(jsonData!['code']);
          break;
        }
      case "callData":
        {
          callData(jsonData!);
        }
        break;
      default:
        {
          debugPrint("没有匹配");
        }
        break;
    }
  }

  void callData(Map<String, dynamic> jsonData) async {
    debugPrint("callData = " +jsonEncode(jsonData));
    String  csrf = Uuid().v1().toString();
    var options = AwesomeAesEncryption.getOptions(csrf: csrf);
    var sdkApi = AwesomeAesEncryption.getSDKApi(widget.isTest);

    Map map = Map();
    final String? callback = jsonData["callback"];
    if(jsonData.containsKey("params")){
      Map<String, dynamic> params = jsonData["params"];
      params.forEach((key, value) {
        map[key] = value;
      });
    }
    map["from"] = "flutter-" + defaultTargetPlatform.toString();
    map["noscan"] = widget.supportScan! ? 0 : 1;
    map["t"] = DateTime.now().millisecondsSinceEpoch;

    var encrypt_key = AwesomeAesEncryption.getEncryptKey(widget.isTest);
    var beforeMD5 = "$encrypt_key${csrf}";
    var keyIv = AwesomeAesEncryption.encodeMd5(beforeMD5);

    Map post_data = Map();
    post_data["post_data"] = AwesomeAesEncryption.dataEncrypt(keyIv, jsonEncode(map));

    debugPrint("post_data = " + jsonEncode(map));

    ResultData resultData = await HttpManager.getInstance(sdkApi)
        .post("?ct=web&ac=get_web_data", post_data,options: options,keyIv: keyIv);

    var result_json = jsonEncode(resultData);

    _webViewController.evaluateJavascript("$callback($result_json)");

  }

  void closePage(int? status) {
    debugPrint("closePage == status=" + status.toString());
    if (status == 0) {
      Navigator.pop(context);
    } else {
      showExitDialog();
    }
  }

  void onAuthResultCall(int errorCode, String? message, String? code) {
    goBackError(errorCode, message, code);
  }

  void onPayResultCall(int? code, String? message, String respJsonData) {
    goBackError(code, message, respJsonData);
  }

  void goBackError(int? errCode, String? msg, String? code) {
    Map<String, dynamic> map = Map();
    map['errCode'] = errCode;
    map['errStr'] = msg;
    //授权的code
    map['code'] = code;
    Navigator.pop(context, map);
  }

  void showExitDialog() {
    String title = "Are you sure to exit?";
    String btn = "Exit";
    if (widget.language == "zh-cn") {
      title = "是否确定退出？";
      btn = "退出";
    } else if (widget.language == "km") {
      title = "តើអ្នកប្រាកដជាចាកចេញឬ?";
      btn = "បោះបង់ការសិក្សា";
    }
    AlertDialog(
      content: Text(title),
      actions: <Widget>[
//        FlatButton(
//          child: Text("取消"),
//          onPressed: () => Navigator.of(context).pop(), //关闭对话框
//        ),
        FlatButton(
          child: Text(btn),
          onPressed: () {
            Navigator.pop(context); //关闭对话框
          },
        ),
      ],
    );
  }



}
